# Alternatives to preview spreadsheets with over 1.000.000 rows

> TODO: improve this draft

## LibreOffice Base
- <https://www.libreoffice.org/discover/base/> <sup>(English)</sup>
- <https://pt-br.libreoffice.org/descubra/base/> <sup>(Português)</sup>

## Microsoft Power Pivot for Excel
- <https://support.microsoft.com/en-us/office/get-started-with-power-pivot-in-microsoft-excel-fdfcf944-7876-424a-8437-1a6c1043a80b> <sup>(English)</sup>
- <https://support.microsoft.com/pt-br/office/power-pivot-vis%C3%A3o-geral-e-aprendizagem-f9001958-7901-4caa-ad80-028a6d2432ed> <sup>(Português)</sup>